summaryrefslogtreecommitdiffstats
path: root/openpgp-ffi/include/sequoia/openpgp.h
diff options
context:
space:
mode:
Diffstat (limited to 'openpgp-ffi/include/sequoia/openpgp.h')
-rw-r--r--openpgp-ffi/include/sequoia/openpgp.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/openpgp-ffi/include/sequoia/openpgp.h b/openpgp-ffi/include/sequoia/openpgp.h
index 7a3d0455..169b3d7a 100644
--- a/openpgp-ffi/include/sequoia/openpgp.h
+++ b/openpgp-ffi/include/sequoia/openpgp.h
@@ -795,10 +795,10 @@ pgp_user_id_binding_iter_t pgp_tpk_user_id_binding_iter (pgp_tpk_t tpk);
/*/
/// Returns an iterator over the live and unrevoked `Key`s in a TPK.
///
/// Compare with `pgp_tpk_keys_iter_valid`, which doesn'filters out
/// expired and revoked keys by default.
/*/
-pgp_tpk_key_iter_t pgp_tpk_keys_iter_all (pgp_tpk_t tpk);
+pgp_tpk_key_iter_t pgp_tpk_key_iter_all (pgp_tpk_t tpk);
/*/
/// Returns an iterator over all `Key`s in a TPK.
@@ -816,10 +816,10 @@ pgp_tpk_key_iter_t pgp_tpk_keys_iter_all (pgp_tpk_t tpk);
///
/// A valid `Key` has at least one good self-signature.
///
/// Compare with `pgp_tpk_keys_iter_all`, which doesn't filter out
/// expired and revoked keys.
/*/
-pgp_tpk_key_iter_t pgp_tpk_keys_iter_valid (pgp_tpk_t tpk);
+pgp_tpk_key_iter_t pgp_tpk_key_iter_valid (pgp_tpk_t tpk);
/*/
/// Returns the TPK's primary user id (if any).
@@ -795,10 +795,10 @@ pgp_user_id_binding_iter_t pgp_tpk_user_id_binding_iter (pgp_tpk_t tpk);
/// Returns an iterator over the live and unrevoked `Key`s in a TPK.
///
-/// Compare with `pgp_tpk_keys_iter_valid`, which doesn'filters out
+/// Compare with `pgp_tpk_key_iter_valid`, which doesn'filters out
/// expired and revoked keys by default.
/*/
@@ -816,10 +816,10 @@ pgp_tpk_key_iter_t pgp_tpk_keys_iter_all (pgp_tpk_t tpk);
/// A valid `Key` has at least one good self-signature.
///
-/// Compare with `pgp_tpk_keys_iter_all`, which doesn't filter out
-/// expired and revoked keys.
+/// Compare with `pgp_tpk_key_iter_all`, which filters out expired and
+/// revoked keys.
/*/